@@ -8,7 +8,7 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 # ---
-# Author: John Egan <john@shopkick.com>
+# Author: John Egan <jwegan@gmail.com>
 
 import functools
 import inspect
@@ -16,7 +16,7 @@ import inspect
 import flawless.client.client
 
 
-def wrap_function(func=None, error_threshold=None, reraise_exception=True):
+def wrap_function(func=None, error_threshold=None, reraise_exception=True, save_current_stack_trace=True):
     ''' Wraps a function with reporting to errors backend '''
     # This if/else allows wrap_function to behave like a normal decorator when
     # used like:
@@ -29,11 +29,15 @@ def wrap_function(func=None, error_threshold=None, reraise_exception=True):
     #         def some_func():
     if func:
         return flawless.client.client._wrap_function_with_error_decorator(
-            func=func, error_threshold=error_threshold, reraise_exception=reraise_exception)
+            func=func,
+            error_threshold=error_threshold,
+            reraise_exception=reraise_exception,
+            save_current_stack_trace=save_current_stack_trace)
     else:
         return functools.partial(flawless.client.client._wrap_function_with_error_decorator,
                                  error_threshold=error_threshold,
-                                 reraise_exception=reraise_exception)
+                                 reraise_exception=reraise_exception,
+                                 save_current_stack_trace=save_current_stack_trace)
 
 
 def wrap_class(cls, error_threshold=None):
@@ -50,3 +54,12 @@ def wrap_class(cls, error_threshold=None):
             wrapped_method = classmethod(wrapped_method)
         setattr(cls, method_name, wrapped_method)
     return cls
+
+
+class WrapClassMetaclass(type):
+    '''Specify FlawlessMetaClass as the metaclass for your class if you want Flawless to wrap a base class
+    that other classes inherit from. Only methods defined in the base class that uses this metaclass will be wrapped.
+    (i.e. new methods defined only in the subclass will not be wrapped)'''
+    def __init__(cls, name, bases, dct):
+        cls = wrap_class(cls)
+        return super(WrapClassMetaclass, cls).__init__(name, bases, dct)
